# Semantic Layer specific dependencies only
# Common dependencies are provided by smarbuy/abi-image:latest

# Vector database and embeddings
weaviate-client>=4.0.0

# ABI Core package
abi-core-ai>=1.7.8
